- Types of Printer Connectors Available
- List out all Printer Connectors
- Get Printer Connectors Configuration for ezeep Hub
- List out all Printer connected with Specific Printer Connector{ID}
- Delete a Connector
ezeep Connectors
The ezeep Print Connector for ezeep Hub and Print Server is software that connects any printer with an ezeep organization. You will learn how to maintain (enumerate, read and delete) ezeep Print Connectors in your organization cloud.
Types of Printer Connectors Available
Two types of Print Connector are available for ezeep:
- ezeep Hub
- Print Server
To get the available connector filter values, call this endpoint:
GET "https://api2.ezeep.com/printing/v1/filter_values/connector/"
| Type | Key | Value |
|---|---|---|
| Header | Authorization | Bearer |
Example Request
curl -X GET "https://api2.ezeep.com/printing/v1/filter_values/connector/" \
--header "Content-Type: application/json" \
--header "Authorization: Bearer <access_token>"
Example Response
[
{
"field_name": "status",
"values": ["ON"]
},
{
"field_name": "type",
"values": ["TPHub", "Printserver"]
}
]
List out all Printer Connectors
Lists all connectors of the organization, of all types, with their id and other attributes.
GET "https://api2.ezeep.com/printing/v1/connectors/"
| Attribute | Type | Required | Description |
|---|---|---|---|
| readable_name | string | yes | unique name of the connector shown in GUI |
| description | string | no | some description shown in GUI |
| type | string | yes | “TPHub”, “Printserver”, “Virtual”, “Embedded” |
| status | string | yes | “Online”, “Offline”, “Inproperly Configured” (printer status) |
| location | string | no | |
| os_type | string | no | “Linux”, “Windows”, “Windows CE” |
| serial_string | string | no | unique device identifier (e.g. model+serial_id |
| supported_formats | string | no | “RAW”, “PDF”, “XPS” |
Example Request
curl -X GET "https://api2.ezeep.com/printing/v1/connectors/" \
--header "Content-Type: application/json" \
--header "Authorization: Bearer <access_token>"
Example Response
{
"count": 2,
"next": null,
"previous": null,
"results": [
{
"id": "534fcfcf-0dbc-4d14-844b-cba482e20b06",
"readable_name": "TPHub-7d44b1",
"description": "",
"type": "TPHub",
"tpuid": 1099182959,
"status": "Online",
"location": null,
"hostname": "TPHub-7d44b1",
"internal_ip": "192.0.2.10",
"external_ip": null,
"os_type": "Raspberry Pi",
"sw_version": "",
"last_seen_online": "2021-08-06T10:19:01.671000Z",
"last_printer_update": "2021-08-18T15:34:44.338898Z",
"organization_id": "11111111-1111-4111-8111-111111111111",
"management_url": null,
"serial_string": null
},
{
"id": "e3b7b77d-b039-45a8-93cf-92e43b41895d",
"readable_name": "Print Server PRINTSRV01",
"description": "",
"type": "Printserver",
"tpuid": 1620342535,
"status": "Online",
"location": null,
"hostname": "printsrv01.example.com",
"internal_ip": null,
"external_ip": null,
"os_type": "Windows",
"sw_version": "",
"last_seen_online": "2021-04-29T22:37:44.156000Z",
"last_printer_update": "2021-06-21T17:47:39.442099Z",
"organization_id": "11111111-1111-4111-8111-111111111111",
"management_url": null,
"serial_string": null
}
]
}
Get Printer Connectors Configuration for ezeep Hub
Lists the ezeep Hub connectors with all their attributes. The connector_id is required by other endpoints.
GET "https://api2.ezeep.com/printing/v1/connectors/?type=TPHub"
| Attribute | Type | Required | Description |
|---|---|---|---|
| type | string | yes | TPHub |
Example Request
curl -X GET "https://api2.ezeep.com/printing/v1/connectors/?type=TPHub" \
--header "Content-Type: application/json" \
--header "Authorization: Bearer <access_token>"
Example Response
{
"count": 1,
"next": null,
"previous": null,
"results": [
{
"id": "534fcfcf-0dbc-4d14-844b-cba482e20b06",
"readable_name": "TPHub-7d44b1",
"description": "",
"type": "TPHub",
"tpuid": 1099182959,
"status": "Online",
"location": null,
"hostname": "TPHub-7d44b1",
"internal_ip": "192.0.2.10",
"external_ip": null,
"os_type": "Raspberry Pi",
"sw_version": "",
"last_seen_online": "2021-08-06T10:19:01.671000Z",
"last_printer_update": "2021-08-18T15:34:44.338898Z",
"organization_id": "11111111-1111-4111-8111-111111111111",
"management_url": null,
"serial_string": null
}
]
}
List out all Printer connected with Specific Printer Connector{ID}
Lists all printers of a connector, for example to assign drivers to them or to add them to groups. This requires the connector_id from the previous request.
GET "https://api2.ezeep.com/printing/v1/printers/?connector_id=<connector_id>"
| Attribute | Type | Required | Description |
|---|---|---|---|
| connector_id | string | yes | uuid of the connector |
Example Request
curl -X GET "https://api2.ezeep.com/printing/v1/printers/?connector_id=534fcfcf-0dbc-4d14-844b-cba482e20b06" \
--header "Content-Type: application/json" \
--header "Authorization: Bearer <access_token>"
Example Response
{
"count": 2,
"next": null,
"previous": null,
"results": [
{
"id": "420309d2-0ae4-46ac-a7c6-61d5878fda93",
"name": "HP Color LaserJet MFP M477fdn",
"tp_id": 1,
"status": "Online",
"vendor_name": "",
"model_name": "HP Color LaserJet MFP M477fdn",
"location": "",
"connector_id": "534fcfcf-0dbc-4d14-844b-cba482e20b06",
"driver_id": null,
"manual_driver_id": "aceac25a-8927-4d80-ac3a-f275453366fe",
"supported_formats": ["RAW"],
"blob_capabilities": {
"Options": 2,
"Count": 6,
"Capabilities": "H4sIAAAAAAACC4VV227TQBA9n5LnKipery/rxxCoBKLwUPEBVVugUptKpSDEh/F9nDkzcRInhkS7Xu/OnJ05c/EZeiyxwg+84AkLXOEODxw3fAcanl3iGhueX3N/gQue3eGW4xn2O0OiTM25xaBVz6fpfaDMC/8m+Yc7Nfd8rlFRqgnpivKg9j5K5rNFFyhfdfccRubcUxOST3wf5NMO7YpWXMuSR44NV4dYppMOUCGEhMK1+9fxb3tv8UvsGF/3+Mn1FKsPy2s+C2cEL+anrwaeD2K9OeFVCi6Kbgffk3AbMbuPtKKk6Rfpl/CkcLhUxRW0576k0G/j/vd4R24WeB04h17kiFAz2tFMYpR5g0l/FsoF8+eBnDz9I1K1kBGWDKOtZpOtPlL7nPsL8rwhu+cTrDJymOQDhG72VuLH7U17WHYyh2ZxcAuz+Iby0dF29/jqDTNxDiftRS2JJwhvKSu3rNeyfok1JeeRWuW+y1dCyhF/z2zHdK/XXB0iZSHlsKmNVatYIiLqGToEV+6d5cGnmUzoxlptwrcslrbRM/8q2XxJxjestGfWx7eJZZ0Qu4hhNWZkEl4R3jaWHdHMZ/Mu4xX15vPB2UrK6U51u8uH4aBuVjw/jn879ow28rKaZHmjil2Sny/M7pv/ZLjJO0f7vbBRFEv0s1t2tFNd0Xuhv2fVbol+0YuPRvYl+ZInrFp29dEJKmlg7Glt+Jn5zNrbVf5xB7J6r6IHN8LJwUkd7GTZ5xk4HxvPYL/XotCqKra98fh7sWZP/a6v0KO+Q/f4fdRdT305rO9br7PfIgbUd4syxH3azl5LGNlxvb8rG67+BgcAAA=="
},
"pnp_id": "",
"auto_driver_assignment_state": "SKIPPED",
"can_modify_favorite": false,
"is_favorite": false
},
{
"id": "ac7b77c1-8853-436b-a6a4-32aac4eb9166",
"name": "HP ENVY Pro 6400 series [C07828]",
"tp_id": 3,
"status": "Online",
"vendor_name": "",
"model_name": "HP",
"location": "",
"connector_id": "534fcfcf-0dbc-4d14-844b-cba482e20b06",
"driver_id": null,
"manual_driver_id": "e1f9898a-7dba-498c-ba56-9c1352a97533",
"supported_formats": ["RAW"],
"blob_capabilities": {
"Options": 1,
"Count": 6,
"Capabilities": "H4sIAAAAAAACC3WQSw7CMAxE31G6rrJI0qSwR1wAxCGQECygEifjfEx+lF8dTeS445c6PZ7IiGHDhTM3jton5RNXOnbKTlop+pfXYQnaUxZVDcoO7NnK/1DN62yl5DeSVbdjUG+slUGrcFwmet11l8JHf+pcv/lmyvdfNE74y5m//5JWC/M00rhIKs72Mla8FF0VeWqfZzOV3US+vzBTPAHsqhhNhgEAAA=="
},
"pnp_id": "",
"auto_driver_assignment_state": "SKIPPED",
"can_modify_favorite": true,
"is_favorite": false
}
]
}
Delete a Connector
DELETE "https://api2.ezeep.com/printing/v1/connectors/<connector_id>/"
| Attribute | Type | Required | Description |
|---|---|---|---|
| connector_id | string | yes | uuid of connector to be deleted |
Example Request
curl -X DELETE "https://api2.ezeep.com/printing/v1/connectors/5924bd45-d86a-41b1-8e18-1e28b574d878/" \
--header "Authorization: Bearer <access_token>"